@@ -2,6 +2,7 @@ import json
 import os
 import shutil
 
+from django.core.cache import cache
 from django.http import (
     HttpResponse,
     HttpResponseNotAllowed,
@@ -11,11 +12,10 @@ from django.http import (
 from django.views.decorators.csrf import csrf_exempt
 from django.views.decorators.cache import never_cache
 
-from PIL import Image as PILImage
-
 from betty.conf.app import settings
 from .decorators import betty_token_auth
-from betty.cropper.models import Image, source_upload_to
+from betty.cropper.models import Image
+
 
 ACC_HEADERS = {
     'Access-Control-Allow-Origin': '*',
@@ -56,25 +56,14 @@ def new(request):
 
     image_file = request.FILES.get("image")
     if image_file is None:
-        return HttpResponseBadRequest(json.dumps({'message': 'No image!'}))
+        return HttpResponseBadRequest(json.dumps({'message': 'No image'}))
 
-    image = Image.objects.create(
-        name=request.POST.get("name") or image_file.name,
+    image = Image.objects.create_from_path(
+        image_file.temporary_file_path(),
+        filename=image_file.name,
+        name=request.POST.get("name"),
         credit=request.POST.get("credit")
     )
-    os.makedirs(image.path())
-    source_path = source_upload_to(image, image_file.name)
-
-    with open(source_path, 'wb+') as f:
-        for chunk in image_file.chunks():
-            f.write(chunk)
-        f.seek(0)
-        img = PILImage.open(f)
-        image.width = img.size[0]
-        image.height = img.size[1]
-
-        image.source.name = source_path
-        image.save()
 
     return HttpResponse(json.dumps(image.to_native()), content_type="application/json")
 
@@ -115,6 +104,7 @@ def update_selection(request, image_id, ratio_slug):
         image.selections = {}
 
     image.selections[ratio_slug] = selection
+    cache.delete("image-{}".format(image.id))
     image.save()
 
     ratio_path = os.path.join(image.path(), ratio_slug)
@@ -172,19 +162,25 @@ def detail(request, image_id):
         for field in ("name", "credit", "selections"):
             if field in request_json:
                 setattr(image, field, request_json[field])
+        cache.delete("image-{}".format(image.id))
         image.save()
 
         return HttpResponse(json.dumps(image.to_native()), content_type="application/json")
 
     @betty_token_auth(["server.image_read"])
     def get(request, image_id):
-        try:
-            image = Image.objects.get(id=image_id)
-        except Image.DoesNotExist:
-            message = json.dumps({"message": "No such image!"})
-            return HttpResponseNotFound(message, content_type="application/json")
+        cache_key = "image-{}".format(image_id)
+        data = cache.get(cache_key)
+        if data is None:
+            try:
+                image = Image.objects.get(id=image_id)
+            except Image.DoesNotExist:
+                message = json.dumps({"message": "No such image!"})
+                return HttpResponseNotFound(message, content_type="application/json")
+            data = image.to_native()
+            cache.set(cache_key, data, 60 * 60)
 
-        return HttpResponse(json.dumps(image.to_native()), content_type="application/json")
+        return HttpResponse(json.dumps(data), content_type="application/json")
 
     if request.method == "PATCH":
         return patch(request, image_id)
